@@ -33,7 +33,7 @@ from distutils.msvccompiler.
 #
 from __future__ import division
 
-__revision__ = "src/engine/SCons/Defaults.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "/src/script/src/engine/SCons/Defaults.py none 2019-08-08 01:09:12 none"
 
 
 import os
@@ -193,7 +193,7 @@ def chmod_func(dest, mode):
     SCons.Node.FS.invalidate_node_memos(dest)
     if not SCons.Util.is_List(dest):
         dest = [dest]
-    if SCons.Util.is_String(mode) and not 0 in [i in digits for i in mode]:
+    if SCons.Util.is_String(mode) and 0 not in [i in digits for i in mode]:
         mode = int(mode, 8)
     if not SCons.Util.is_String(mode):
         for element in dest:
@@ -210,7 +210,7 @@ def chmod_func(dest, mode):
             else:
                 raise SyntaxError("Could not find +, - or =")
             operation_list = operation.split(operator)
-            if len(operation_list) is not 2:
+            if len(operation_list) != 2:
                 raise SyntaxError("More than one operator found")
             user = operation_list[0].strip().replace("a", "ugo")
             permission = operation_list[1].strip()
@@ -333,8 +333,8 @@ def touch_func(dest):
         if os.path.exists(file):
             atime = os.path.getatime(file)
         else:
-            open(file, 'w')
-            atime = mtime
+            with open(file, 'w'):
+                atime = mtime
         os.utime(file, (atime, mtime))
 
 Touch = ActionFactory(touch_func,
@@ -582,6 +582,7 @@ ConstructionEnvironment = {
     '__DSHLIBVERSIONFLAGS'   : '${__libversionflags(__env__,"DSHLIBVERSION","_DSHLIBVERSIONFLAGS")}',
 
     'TEMPFILE'      : NullCmdGenerator,
+    'TEMPFILEARGJOIN': ' ',
     'Dir'           : Variable_Method_Caller('TARGET', 'Dir'),
     'Dirs'          : Variable_Method_Caller('TARGET', 'Dirs'),
     'File'          : Variable_Method_Caller('TARGET', 'File'),
