@@ -28,7 +28,7 @@ and user errors in SCons.
 
 """
 
-__revision__ = "src/engine/SCons/Errors.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "/src/script/src/engine/SCons/Errors.py none 2019-08-08 03:09:12 none"
 
 import shutil
 import SCons.Util
@@ -124,7 +124,7 @@ class UserError(Exception):
 class StopError(Exception):
     pass
 
-class EnvironmentError(Exception):
+class SConsEnvironmentError(Exception):
     pass
 
 class MSVCError(IOError):
@@ -184,7 +184,7 @@ def convert_to_BuildError(status, exc_info=None):
             filename=filename,
             exc_info=exc_info)
 
-    elif isinstance(status, (EnvironmentError, OSError, IOError)):
+    elif isinstance(status, (SConsEnvironmentError, OSError, IOError)):
         # If an IOError/OSError happens, raise a BuildError.
         # Report the name of the file or directory that caused the
         # error, which might be different from the target being built
