@@ -6,7 +6,7 @@ Nodes.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -26,8 +26,9 @@ Nodes.
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+from __future__ import print_function
 
-__revision__ = "src/engine/SCons/Executor.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "/src/script/src/engine/SCons/Executor.py none 2019-08-08 03:09:12 none"
 
 import collections
 
@@ -35,15 +36,16 @@ import SCons.Debug
 from SCons.Debug import logInstanceCreation
 import SCons.Errors
 import SCons.Memoize
-
+import SCons.Util
+from SCons.compat import with_metaclass, NoSlotsPyPy
 
 class Batch(object):
     """Remembers exact association between targets
     and sources of executor."""
-    
+
     __slots__ = ('targets',
                  'sources')
-    
+
     def __init__(self, targets=[], sources=[]):
         self.targets = targets
         self.sources = sources
@@ -70,7 +72,7 @@ class TSList(collections.UserList):
         return nl[i]
     def __getslice__(self, i, j):
         nl = self.func()
-        i = max(i, 0); j = max(j, 0)
+        i, j = max(i, 0), max(j, 0)
         return nl[i:j]
     def __str__(self):
         nl = self.func()
@@ -122,18 +124,17 @@ def execute_action_list(obj, target, kw):
     kw = obj.get_kw(kw)
     status = 0
     for act in obj.get_action_list():
-        #args = (self.get_all_targets(), self.get_all_sources(), env)
         args = ([], [], env)
         status = act(*args, **kw)
         if isinstance(status, SCons.Errors.BuildError):
             status.executor = obj
-            raise status
+            raise status    # TODO pylint E0702: raising int not allowed
         elif status:
             msg = "Error %s" % status
             raise SCons.Errors.BuildError(
-                errstr=msg, 
+                errstr=msg,
                 node=obj.batches[0].targets,
-                executor=obj, 
+                executor=obj,
                 action=act)
     return status
 
@@ -155,7 +156,7 @@ _execute_str_map = {0 : execute_null_str,
                     1 : execute_actions_str}
 
 
-class Executor(object):
+class Executor(object, with_metaclass(NoSlotsPyPy)):
     """A class for controlling instances of executing an action.
 
     This largely exists to hold a single association of an action,
@@ -218,7 +219,9 @@ class Executor(object):
         us = []
         ut = []
         for b in self.batches:
-            if b.targets[0].is_up_to_date():
+            # don't add targets marked always build to unchanged lists
+            # add to changed list as they always need to build
+            if not b.targets[0].always_build and b.targets[0].is_up_to_date():
                 us.extend(list(map(rfile, b.sources)))
                 ut.extend(b.targets)
             else:
@@ -244,14 +247,12 @@ class Executor(object):
             return self._changed_targets_list
 
     def _get_source(self, *args, **kw):
-        #return SCons.Util.NodeList([rfile(self.batches[0].sources[0]).get_subst_proxy()])
         return rfile(self.batches[0].sources[0]).get_subst_proxy()
 
     def _get_sources(self, *args, **kw):
         return SCons.Util.NodeList([rfile(n).get_subst_proxy() for n in self.get_all_sources()])
 
     def _get_target(self, *args, **kw):
-        #return SCons.Util.NodeList([self.batches[0].targets[0].get_subst_proxy()])
         return self.batches[0].targets[0].get_subst_proxy()
 
     def _get_targets(self, *args, **kw):
@@ -450,16 +451,24 @@ class Executor(object):
         """Fetch the signature contents.  This is the main reason this
         class exists, so we can compute this once and cache it regardless
         of how many target or source Nodes there are.
+
+        Returns bytes
         """
         try:
             return self._memo['get_contents']
         except KeyError:
             pass
         env = self.get_build_env()
-        result = "".join([action.get_contents(self.get_all_targets(),
-                                              self.get_all_sources(),
-                                              env)
-                          for action in self.get_action_list()])
+
+        action_list = self.get_action_list()
+        all_targets = self.get_all_targets()
+        all_sources = self.get_all_sources()
+
+        result = bytearray("",'utf-8').join([action.get_contents(all_targets,
+                                                                 all_sources,
+                                                                 env)
+                                             for action in action_list])
+
         self._memo['get_contents'] = result
         return result
 
@@ -486,29 +495,15 @@ class Executor(object):
         each individual target, which is a hell of a lot more efficient.
         """
         env = self.get_build_env()
+        path = self.get_build_scanner_path
+        kw = self.get_kw()
 
         # TODO(batch):  scan by batches)
         deps = []
-        if scanner:
-            for node in node_list:
-                node.disambiguate()
-                s = scanner.select(node)
-                if not s:
-                    continue
-                path = self.get_build_scanner_path(s)
-                deps.extend(node.get_implicit_deps(env, s, path))
-        else:
-            kw = self.get_kw()
-            for node in node_list:
-                node.disambiguate()
-                scanner = node.get_env_scanner(env, kw)
-                if not scanner:
-                    continue
-                scanner = scanner.select(node)
-                if not scanner:
-                    continue
-                path = self.get_build_scanner_path(scanner)
-                deps.extend(node.get_implicit_deps(env, scanner, path))
+
+        for node in node_list:
+            node.disambiguate()
+            deps.extend(node.get_implicit_deps(env, scanner, path, kw))
 
         deps.extend(self.get_implicit_deps())
 
@@ -578,7 +573,6 @@ def AddBatchExecutor(key, executor):
 nullenv = None
 
 
-import SCons.Util
 class NullEnvironment(SCons.Util.Null):
     import SCons.CacheDir
     _CacheDir_path = None
@@ -595,7 +589,7 @@ def get_NullEnvironment():
         nullenv = NullEnvironment()
     return nullenv
 
-class Null(object):
+class Null(object, with_metaclass(NoSlotsPyPy)):
     """A null Executor, with a null build Environment, that does
     nothing when the rest of the methods call it.
 
@@ -603,7 +597,7 @@ class Null(object):
     disassociate Builders from Nodes entirely, so we're not
     going to worry about unit tests for this--at least for now.
     """
-    
+
     __slots__ = ('pre_actions',
                  'post_actions',
                  'env',
@@ -619,9 +613,10 @@ class Null(object):
                  'action_list',
                  '_do_execute',
                  '_execute_str')
-    
+
     def __init__(self, *args, **kw):
-        if SCons.Debug.track_instances: logInstanceCreation(self, 'Executor.Null')
+        if SCons.Debug.track_instances:
+            logInstanceCreation(self, 'Executor.Null')
         self.batches = [Batch(kw['targets'][:], [])]
     def get_build_env(self):
         return get_NullEnvironment()
@@ -655,7 +650,7 @@ class Null(object):
         """Morph this Null executor to a real Executor object."""
         batches = self.batches
         self.__class__ = Executor
-        self.__init__([])            
+        self.__init__([])
         self.batches = batches
 
     # The following methods require morphing this Null Executor to a
