@@ -8,7 +8,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2018 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -30,7 +30,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Platform/darwin.py 425375072d7b582a2df0db815c8eaeaa489468ab 2019-01-01 18:32:02 bdbaddog"
+__revision__ = "/src/script/src/engine/SCons/Platform/darwin.py none 2019-08-08 03:09:12 none"
 
 from . import posix
 import os
@@ -56,12 +56,11 @@ def generate(env):
 
     for file in filelist:
         if os.path.isfile(file):
-            f = open(file, 'r')
-            lines = f.readlines()
-            for line in lines:
-                if line:
-                    env.AppendENVPath('PATHOSX', line.strip('\n'))
-            f.close()
+            with open(file, 'r') as f:
+                lines = f.readlines()
+                for line in lines:
+                    if line:
+                        env.AppendENVPath('PATHOSX', line.strip('\n'))
 
     # Not sure why this wasn't the case all along?
     if env['ENV'].get('PATHOSX', False) and os.environ.get('SCONS_USE_MAC_PATHS', False):
