@@ -30,7 +30,7 @@ Coded by Andy Friesen
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Scanner/D.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "/src/script/src/engine/SCons/Scanner/D.py none 2019-08-08 03:09:12 none"
 
 import SCons.Scanner
 
@@ -46,7 +46,7 @@ class D(SCons.Scanner.Classic):
             name = "DScanner",
             suffixes = '$DSUFFIXES',
             path_variable = 'DPATH',
-            regex = '(?:import\s+)([\w\s=,.]+)(?:\s*:[\s\w,=]+)?(?:;)'
+            regex = r'(?:import\s+)([\w\s=,.]+)(?:\s*:[\s\w,=]+)?(?:;)'
         )
 
     def find_include(self, include, source_dir, path):
