@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001 - 2018 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/MSCommon/vs.py 425375072d7b582a2df0db815c8eaeaa489468ab 2019-01-01 18:32:02 bdbaddog"
+__revision__ = "/src/script/src/engine/SCons/Tool/MSCommon/vs.py none 2019-08-08 03:09:12 none"
 
 __doc__ = """Module to detect Visual Studio and/or Visual C/C++
 """
@@ -68,9 +68,9 @@ class VisualStudio(object):
         SCons.Tool.MSCommon.vc.get_installed_vcs()
         dir = SCons.Tool.MSCommon.vc.find_vc_pdir(self.vc_version)
         if not dir:
-            debug('find_vs_dir():  no installed VC %s' % self.vc_version)
+            debug('find_vs_dir_by_vc():  no installed VC %s' % self.vc_version)
             return None
-        return dir
+        return os.path.abspath(os.path.join(dir, os.pardir))
 
     def find_vs_dir_by_reg(self):
         root = 'Software\\'
@@ -95,12 +95,11 @@ class VisualStudio(object):
         First try to find by registry, and if that fails find via VC dir
         """
 
-
-        if True:
-            vs_dir=self.find_vs_dir_by_reg()
-            return vs_dir
-        else:
-            return self.find_vs_dir_by_vc()
+        vs_dir=self.find_vs_dir_by_reg()
+        if not vs_dir:
+            vs_dir = self.find_vs_dir_by_vc()
+        debug('find_vs_dir(): found VS in ' + str(vs_dir ))
+        return vs_dir
 
     def find_executable(self):
         vs_dir = self.get_vs_dir()
@@ -199,6 +198,17 @@ class VisualStudio(object):
 # Tool/MSCommon/vc.py, and the MSVC_VERSION documentation in Tool/msvc.xml.
 
 SupportedVSList = [
+    # Visual Studio 2019
+    VisualStudio('14.2',
+                 vc_version='14.2',
+                 sdk_version='10.0A',
+                 hkeys=[],
+                 common_tools_var='VS160COMNTOOLS',
+                 executable_path=r'Common7\IDE\devenv.com',
+                 batch_file_path=r'VC\Auxiliary\Build\vsvars32.bat',
+                 supported_arch=['x86', 'amd64', "arm"],
+                 ),
+
     # Visual Studio 2017
     VisualStudio('14.1',
                  vc_version='14.1',
@@ -521,7 +531,7 @@ def get_default_arch(env):
 
     if not msvs:
         arch = 'x86'
-    elif not arch in msvs.get_supported_arch():
+    elif arch not in msvs.get_supported_arch():
         fmt = "Visual Studio version %s does not support architecture %s"
         raise SCons.Errors.UserError(fmt % (env['MSVS_VERSION'], arch))
 
