@@ -33,7 +33,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-# __revision__ = "src/engine/SCons/Tool/clangxx.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+# __revision__ = "/src/script/src/engine/SCons/Tool/clangxx.py none 2019-08-08 03:09:12 none"
 
 # Based on SCons/Tool/g++.py by Paweł Tomulik 2014 as a separate tool.
 # Brought into the SCons mainline by Russel Winder 2017.
@@ -85,7 +85,8 @@ def generate(env):
             return
         
         # clang -dumpversion is of no use
-        line = pipe.stdout.readline()
+        with pipe.stdout:
+            line = pipe.stdout.readline()
         if sys.version_info[0] > 2:
             line = line.decode()
         match = re.search(r'clang +version +([0-9]+(?:\.[0-9]+)+)', line)
