@@ -33,7 +33,7 @@ packages fake_root.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/ipkg.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "/src/script/src/engine/SCons/Tool/ipkg.py none 2019-08-08 03:09:12 none"
 
 import os
 
@@ -55,8 +55,10 @@ def generate(env):
     env['IPKGCOM'] = '$IPKG $IPKGFLAGS ${SOURCE}'
 
     if env.WhereIs('id'):
-        env['IPKGUSER'] = os.popen('id -un').read().strip()
-        env['IPKGGROUP'] = os.popen('id -gn').read().strip()
+        with os.popen('id -un') as p:
+            env['IPKGUSER'] = p.read().strip()
+        with os.popen('id -gn') as p:
+            env['IPKGGROUP'] = p.read().strip()
     env['IPKGFLAGS'] = SCons.Util.CLVar('-o $IPKGUSER -g $IPKGGROUP')
     env['IPKGSUFFIX'] = '.ipk'
 
