@@ -25,7 +25,7 @@ SCons Packaging Tool.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/packaging/__init__.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "/src/script/src/engine/SCons/Tool/packaging/__init__.py none 2019-08-08 01:09:12 none"
 
 import SCons.Defaults
 import SCons.Environment
@@ -35,11 +35,11 @@ from SCons.Util import is_List, make_path_relative
 from SCons.Warnings import warn, Warning
 
 import os
-import imp
+import importlib
 
 __all__ = [
-    'src_targz', 'src_tarbz2', 'src_xz', 'src_zip',
-    'targz', 'tarbz2', 'xz', 'zip',
+    'src_targz', 'src_tarbz2', 'src_tarxz', 'src_zip',
+    'targz', 'tarbz2', 'tarxz', 'zip',
     'rpm', 'msi', 'ipk',
 ]
 
@@ -122,12 +122,12 @@ def Package(env, target=None, source=None, **kw):
     # load the needed packagers.
     def load_packager(type):
         try:
-            file,path,desc=imp.find_module(type, __path__)
-            return imp.load_module(type, file, path, desc)
+            # the specific packager is a relative import
+            return importlib.import_module("." + type, __name__)
         except ImportError as e:
-            raise EnvironmentError("packager %s not available: %s"%(type,str(e)))
+            raise SConsEnvironmentError("packager %s not available: %s" % (type, str(e)))
 
-    packagers=list(map(load_packager, PACKAGETYPE))
+    packagers = list(map(load_packager, PACKAGETYPE))
 
     # set up targets and the PACKAGEROOT
     try:
