@@ -25,7 +25,7 @@ The rpm packager.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/packaging/rpm.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "/src/script/src/engine/SCons/Tool/packaging/rpm.py none 2019-08-08 01:09:12 none"
 
 import os
 
@@ -125,11 +125,11 @@ def build_specfile(target, source, env):
     """ Builds a RPM specfile from a dictionary with string metadata and
     by analyzing a tree of nodes.
     """
-    with open(target[0].get_abspath(), 'w') as file:
+    with open(target[0].get_abspath(), 'w') as ofp:
         try:
-            file.write(build_specfile_header(env))
-            file.write(build_specfile_sections(env))
-            file.write(build_specfile_filesection(env, source))
+            ofp.write(build_specfile_header(env))
+            ofp.write(build_specfile_sections(env))
+            ofp.write(build_specfile_filesection(env, source))
 
             # call a user specified function
             if 'CHANGE_SPECFILE' in env:
