@@ -31,7 +31,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/rmic.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "/src/script/src/engine/SCons/Tool/rmic.py none 2019-08-08 03:09:12 none"
 
 import os.path
 
@@ -110,11 +110,9 @@ def generate(env):
 
     if env['PLATFORM'] == 'win32':
         version = env.get('JAVAVERSION', None)
-        default_paths=get_java_install_dirs(env['PLATFORM'], version=version)
-
         # Ensure that we have a proper path for rmic
-        rmic = SCons.Tool.find_program_path(env, 'rmic', default_paths=default_paths)
-
+        paths = get_java_install_dirs('win32', version=version)
+        rmic = SCons.Tool.find_program_path(env, 'rmic', default_paths=paths)
         # print("RMIC: %s"%rmic)
         if rmic:
             rmic_bin_dir = os.path.dirname(rmic)
