@@ -10,7 +10,7 @@ selection method.
 from __future__ import print_function
 
 #
-# Copyright (c) 2001 - 2018 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -32,7 +32,7 @@ from __future__ import print_function
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/swig.py 425375072d7b582a2df0db815c8eaeaa489468ab 2019-01-01 18:32:02 bdbaddog"
+__revision__ = "/src/script/src/engine/SCons/Tool/swig.py none 2019-08-08 03:09:12 none"
 
 import os.path
 import sys
@@ -70,7 +70,9 @@ def _find_modules(src):
     directors = 0
     mnames = []
     try:
-        matches = _reModule.findall(open(src).read())
+        with open(src) as f:
+            data = f.read()
+        matches = _reModule.findall(data)
     except IOError:
         # If the file's not yet generated, guess the module name from the file stem
         matches = []
@@ -135,21 +137,31 @@ def _swigEmitter(target, source, env):
 
 def _get_swig_version(env, swig):
     """Run the SWIG command line tool to get and return the version number"""
+    version = None
     swig = env.subst(swig)
+    if not swig:
+        return version
     pipe = SCons.Action._subproc(env, SCons.Util.CLVar(swig) + ['-version'],
                                  stdin = 'devnull',
                                  stderr = 'devnull',
                                  stdout = subprocess.PIPE)
-    if pipe.wait() != 0: return
+    if pipe.wait() != 0:
+        return version
 
     # MAYBE:   out = SCons.Util.to_str (pipe.stdout.read())
-    out = SCons.Util.to_str(pipe.stdout.read())
-    match = re.search('SWIG Version\s+(\S+).*', out, re.MULTILINE)
+    with pipe.stdout:
+        out = SCons.Util.to_str(pipe.stdout.read())
+
+    match = re.search(r'SWIG Version\s+(\S+).*', out, re.MULTILINE)
     if match:
-        if verbose: print("Version is:%s"%match.group(1))
-        return match.group(1)
+        version = match.group(1)
+        if verbose:
+            print("Version is: %s" % version)
     else:
-        if verbose: print("Unable to detect version: [%s]"%out)
+        if verbose:
+            print("Unable to detect version: [%s]" % out)
+
+    return version
 
 def generate(env):
     """Add Builders and construction variables for swig to an Environment."""
@@ -172,9 +184,10 @@ def generate(env):
 
     from SCons.Platform.mingw import MINGW_DEFAULT_PATHS
     from SCons.Platform.cygwin import CYGWIN_DEFAULT_PATHS
+    from SCons.Platform.win32 import CHOCO_DEFAULT_PATH
 
     if sys.platform == 'win32':
-        swig = SCons.Tool.find_program_path(env, 'swig', default_paths=MINGW_DEFAULT_PATHS + CYGWIN_DEFAULT_PATHS + [r'C:\ProgramData\chocolatey\bin'] )
+        swig = SCons.Tool.find_program_path(env, 'swig', default_paths=MINGW_DEFAULT_PATHS + CYGWIN_DEFAULT_PATHS + CHOCO_DEFAULT_PATH)
         if swig:
             swig_bin_dir = os.path.dirname(swig)
             env.AppendENVPath('PATH', swig_bin_dir)
