@@ -31,7 +31,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/yacc.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "/src/script/src/engine/SCons/Tool/yacc.py none 2019-08-08 01:09:12 none"
 
 import os.path
 import sys
@@ -41,9 +41,15 @@ import SCons.Tool
 import SCons.Util
 from SCons.Platform.mingw import MINGW_DEFAULT_PATHS
 from SCons.Platform.cygwin import CYGWIN_DEFAULT_PATHS
+from SCons.Platform.win32 import CHOCO_DEFAULT_PATH
 
 YaccAction = SCons.Action.Action("$YACCCOM", "$YACCCOMSTR")
 
+if sys.platform == 'win32':
+    BINS = ['bison', 'yacc', 'win_bison']
+else:
+    BINS = ["bison", "yacc"]
+
 def _yaccEmitter(target, source, env, ysuf, hsuf):
     yaccflags = env.subst("$YACCFLAGS", target=target, source=source)
     flags = SCons.Util.CLVar(yaccflags)
@@ -97,6 +103,29 @@ def ymEmitter(target, source, env):
 def yyEmitter(target, source, env):
     return _yaccEmitter(target, source, env, ['.yy'], '$YACCHXXFILESUFFIX')
 
+def get_yacc_path(env, append_paths=False):
+    """
+    Find the path to the yacc tool, searching several possible names
+
+    Only called in the Windows case, so the default_path
+    can be Windows-specific
+
+    :param env: current construction environment
+    :param append_paths: if set, add the path to the tool to PATH
+    :return: path to yacc tool, if found
+    """
+    for prog in BINS:
+        bin_path = SCons.Tool.find_program_path(
+            env,
+            prog,
+            default_paths=CHOCO_DEFAULT_PATH + MINGW_DEFAULT_PATHS + CYGWIN_DEFAULT_PATHS )
+        if bin_path:
+            if append_paths:
+                env.AppendENVPath('PATH', os.path.dirname(bin_path))
+            return bin_path
+    SCons.Warnings.Warning('yacc tool requested, but yacc or bison binary not found in ENV PATH')
+
+
 def generate(env):
     """Add Builders and construction variables for yacc to an Environment."""
     c_file, cxx_file = SCons.Tool.createCFileBuilders(env)
@@ -117,24 +146,21 @@ def generate(env):
     cxx_file.add_emitter('.yy', yyEmitter)
 
     if sys.platform == 'win32':
-        bison = SCons.Tool.find_program_path(env, 'bison', default_paths=MINGW_DEFAULT_PATHS + CYGWIN_DEFAULT_PATHS )
-        if bison:
-            bison_bin_dir = os.path.dirname(bison)
-            env.AppendENVPath('PATH', bison_bin_dir)
-        else:
-            SCons.Warnings.Warning('yacc tool requested, but bison binary not found in ENV PATH')
+        # ignore the return, all we need is for the path to be added
+        _ = get_yacc_path(env, append_paths=True)
 
-    env['YACC']      = env.Detect('bison') or 'yacc'
+    env["YACC"] = env.Detect(BINS)
     env['YACCFLAGS'] = SCons.Util.CLVar('')
     env['YACCCOM']   = '$YACC $YACCFLAGS -o $TARGET $SOURCES'
     env['YACCHFILESUFFIX'] = '.h'
-
     env['YACCHXXFILESUFFIX'] = '.hpp'
-
     env['YACCVCGFILESUFFIX'] = '.vcg'
 
 def exists(env):
-    return env.Detect(['bison', 'yacc'])
+    if sys.platform == 'win32':
+        return get_yacc_path(env)
+    else:
+        return env.Detect(BINS)
 
 # Local Variables:
 # tab-width:4
