@@ -37,7 +37,7 @@ Usage example::
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Variables/EnumVariable.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "/src/script/src/engine/SCons/Variables/EnumVariable.py none 2019-08-08 01:09:12 none"
 
 __all__ = ['EnumVariable',]
 
@@ -45,7 +45,7 @@ __all__ = ['EnumVariable',]
 import SCons.Errors
 
 def _validator(key, val, env, vals):
-    if not val in vals:
+    if val not in vals:
         raise SCons.Errors.UserError(
             'Invalid value for option %s: %s.  Valid values are: %s' % (key, val, vals))
 
