@@ -46,7 +46,7 @@ Usage example::
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Variables/ListVariable.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "/src/script/src/engine/SCons/Variables/ListVariable.py none 2019-08-08 03:09:12 none"
 
 # Known Bug: This should behave like a Set-Type, but does not really,
 # since elements can occur twice.
@@ -96,7 +96,7 @@ def _converter(val, allowedElems, mapdict):
     else:
         val = [_f for _f in val.split(',') if _f]
         val = [mapdict.get(v, v) for v in val]
-        notAllowed = [v for v in val if not v in allowedElems]
+        notAllowed = [v for v in val if v not in allowedElems]
         if notAllowed:
             raise ValueError("Invalid value(s) for option: %s" %
                              ','.join(notAllowed))
