@@ -5,7 +5,7 @@ customizable variables to an SCons build.
 """
 
 #
-# Copyright (c) 2001 - 2018 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -26,7 +26,7 @@ customizable variables to an SCons build.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Variables/__init__.py 425375072d7b582a2df0db815c8eaeaa489468ab 2019-01-01 18:32:02 bdbaddog"
+__revision__ = "/src/script/src/engine/SCons/Variables/__init__.py none 2019-08-08 03:09:12 none"
 
 import os.path
 import sys
@@ -99,7 +99,7 @@ class Variables(object):
         option.converter = converter
 
         self.options.append(option)
-        
+
         # options might be added after the 'unknown' dict has been set up,
         # so we remove the key and all its aliases from that dict
         for alias in list(option.aliases) + [ option.key ]:
@@ -168,7 +168,7 @@ class Variables(object):
 
         # first set the defaults:
         for option in self.options:
-            if not option.default is None:
+            if option.default is not None:
                 values[option.key] = option.default
 
         # next set the value specified in the options file
@@ -288,7 +288,7 @@ class Variables(object):
 
         env - an environment that is used to get the current values
               of the options.
-        cmp - Either a function as follows: The specific sort function should take two arguments and return -1, 0 or 1 
+        cmp - Either a function as follows: The specific sort function should take two arguments and return -1, 0 or 1
               or a boolean to indicate if it should be sorted.
         """
 
