@@ -5,7 +5,7 @@ The main package for the SCons software construction utility.
 """
 
 #
-# __COPYRIGHT__
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -27,17 +27,17 @@ The main package for the SCons software construction utility.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
+__revision__ = "/src/script/src/engine/SCons/__init__.py none 2019-08-08 03:09:12 none"
 
-__version__ = "__VERSION__"
+__version__ = "3.1.1"
 
 __build__ = "__BUILD__"
 
-__buildsys__ = "__BUILDSYS__"
+__buildsys__ = "none"
 
-__date__ = "__DATE__"
+__date__ = "2019-08-08 03:09:12"
 
-__developer__ = "__DEVELOPER__"
+__developer__ = "none"
 
 # make sure compatibility is always in place
 import SCons.compat
